---
title: rbf
sidebarTitle: rbf
---

# `catalax.neural.rbf`

## Classes

### `RBFLayer` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/neural/rbf.py#L8" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>
